mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* [PATCH 2.6.12-rc5] m32r: Update m32r_cfc.[ch] to support Mappi-III platform
@ 2005-05-31 13:17 Hirokazu Takata
  2005-05-31 14:19 ` Christoph Hellwig
  2005-05-31 14:45 ` Dominik Brodowski
  0 siblings, 2 replies; 5+ messages in thread
From: Hirokazu Takata @ 2005-05-31 13:17 UTC (permalink / raw)
  To: Andrew Morton; +Cc: linux-kernel, linux-pcmcia, sakugawa, takata

Hello,

This patch is for the M32R CF/PCMCIA drivers to support a new platform,
Mappi-III evaluation board.

Regards,

Signed-off-by: Mamoru Sakugawa <sakugawa@linux-m32r.org>
Signed-off-by: Hirokazu Takata <takata@linux-m32r.org>
---

 drivers/pcmcia/Kconfig    |    4 +--
 drivers/pcmcia/m32r_cfc.c |   57 ++++++++++++++++++----------------------------
 drivers/pcmcia/m32r_cfc.h |    8 ++++--
 3 files changed, 31 insertions(+), 38 deletions(-)


diff -ruNp a/drivers/pcmcia/Kconfig b/drivers/pcmcia/Kconfig
--- a/drivers/pcmcia/Kconfig	2005-05-26 18:54:43.000000000 +0900
+++ b/drivers/pcmcia/Kconfig	2005-05-26 21:27:15.000000000 +0900
@@ -176,14 +176,14 @@ config M32R_PCC
 
 config M32R_CFC
 	bool "M32R CF I/F Controller"
-	depends on M32R && (PLAT_USRV || PLAT_M32700UT || PLAT_MAPPI2 || PLAT_OPSPUT)
+	depends on M32R && (PLAT_USRV || PLAT_M32700UT || PLAT_MAPPI2 || PLAT_MAPPI3 || PLAT_OPSPUT)
 	help
 	  Say Y here to use the M32R CompactFlash controller.
 
 config M32R_CFC_NUM
 	int "M32R CF I/F number"
 	depends on M32R_CFC
-	default "1" if PLAT_USRV || PLAT_M32700UT || PLAT_MAPPI2 || PLAT_OPSPUT
+	default "1" if PLAT_USRV || PLAT_M32700UT || PLAT_MAPPI2 || PLAT_MAPPI3 || PLAT_OPSPUT
 	help
 	  Set the number of M32R CF slots.
 
diff -ruNp a/drivers/pcmcia/m32r_cfc.h b/drivers/pcmcia/m32r_cfc.h
--- a/drivers/pcmcia/m32r_cfc.h	2004-12-25 06:34:26.000000000 +0900
+++ b/drivers/pcmcia/m32r_cfc.h	2005-05-26 21:17:46.000000000 +0900
@@ -71,11 +71,15 @@
 
 #define CFC_IOPORT_BASE		0x1000
 
-#if !defined(CONFIG_PLAT_USRV)
+#if defined(CONFIG_PLAT_MAPPI3)
+#define CFC_ATTR_MAPBASE	0x14014000
+#define CFC_IO_MAPBASE_BYTE	0xb4012000
+#define CFC_IO_MAPBASE_WORD	0xb4002000
+#elif !defined(CONFIG_PLAT_USRV)
 #define CFC_ATTR_MAPBASE        0x0c014000
 #define CFC_IO_MAPBASE_BYTE     0xac012000
 #define CFC_IO_MAPBASE_WORD     0xac002000
-#else	/* CONFIG_PLAT_USRV */
+#else	
 #define CFC_ATTR_MAPBASE	0x04014000
 #define CFC_IO_MAPBASE_BYTE	0xa4012000
 #define CFC_IO_MAPBASE_WORD	0xa4002000

--
Hirokazu Takata <takata@linux-m32r.org>
Linux/M32R Project:  http://www.linux-m32r.org/


^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH 2.6.12-rc5] m32r: Update m32r_cfc.[ch] to support Mappi-III platform
  2005-05-31 13:17 [PATCH 2.6.12-rc5] m32r: Update m32r_cfc.[ch] to support Mappi-III platform Hirokazu Takata
@ 2005-05-31 14:19 ` Christoph Hellwig
  2005-05-31 14:45 ` Dominik Brodowski
  1 sibling, 0 replies; 5+ messages in thread
From: Christoph Hellwig @ 2005-05-31 14:19 UTC (permalink / raw)
  To: Hirokazu Takata; +Cc: Andrew Morton, linux-pcmcia, sakugawa, linux-kernel

On Tue, May 31, 2005 at 10:17:02PM +0900, Hirokazu Takata wrote:
> Hello,
> 
> This patch is for the M32R CF/PCMCIA drivers to support a new platform,
> Mappi-III evaluation board.

Any chance you could cleanup the ifdef mess a little? e.g. adding a new
file for each platform and proper abstractions in the main source file.


^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH 2.6.12-rc5] m32r: Update m32r_cfc.[ch] to support Mappi-III platform
  2005-05-31 13:17 [PATCH 2.6.12-rc5] m32r: Update m32r_cfc.[ch] to support Mappi-III platform Hirokazu Takata
  2005-05-31 14:19 ` Christoph Hellwig
@ 2005-05-31 14:45 ` Dominik Brodowski
  2005-06-01 11:57   ` Hirokazu Takata
  1 sibling, 1 reply; 5+ messages in thread
From: Dominik Brodowski @ 2005-05-31 14:45 UTC (permalink / raw)
  To: Hirokazu Takata; +Cc: Andrew Morton, linux-pcmcia, sakugawa, linux-kernel

Hi,

> @@ -825,7 +814,7 @@ static int __init init_m32r_pcc(void)
>  	for (i = 0 ; i < pcc_sockets ; i++) {
>  		socket[i].socket.dev.dev = &pcc_device.dev;
>  		socket[i].socket.ops = &pcc_operations;
> -		socket[i].socket.resource_ops = &pccard_static_ops;
> +		socket[i].socket.resource_ops = &pccard_nonstatic_ops;
>  		socket[i].socket.owner = THIS_MODULE;
>  		socket[i].number = i;
>  		ret = pcmcia_register_socket(&socket[i].socket);

Uh, are you sure?

	Dominik

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH 2.6.12-rc5] m32r: Update m32r_cfc.[ch] to support Mappi-III platform
  2005-05-31 14:45 ` Dominik Brodowski
@ 2005-06-01 11:57   ` Hirokazu Takata
  2005-06-02 10:11     ` [PATCH 2.6.12-rc5-mm2] m32r: m32r_cfc.c build fix Hirokazu Takata
  0 siblings, 1 reply; 5+ messages in thread
From: Hirokazu Takata @ 2005-06-01 11:57 UTC (permalink / raw)
  To: linux; +Cc: takata, akpm, linux-pcmcia, sakugawa, linux-kernel

Hi,

From: Dominik Brodowski <linux@dominikbrodowski.net>
Date: Tue, 31 May 2005 16:45:04 +0200
> Hi,
> 
> > @@ -825,7 +814,7 @@ static int __init init_m32r_pcc(void)
> >  	for (i = 0 ; i < pcc_sockets ; i++) {
> >  		socket[i].socket.dev.dev = &pcc_device.dev;
> >  		socket[i].socket.ops = &pcc_operations;
> > -		socket[i].socket.resource_ops = &pccard_static_ops;
> > +		socket[i].socket.resource_ops = &pccard_nonstatic_ops;
> >  		socket[i].socket.owner = THIS_MODULE;
> >  		socket[i].number = i;
> >  		ret = pcmcia_register_socket(&socket[i].socket);
> 
> Uh, are you sure?
> 
> 	Dominik
> 

I'm now in trouble with CF device detection at boot time in case of
pccard_static_ops.

I guess it has a relationship with that CS_UNSUPPORTED_FUNCTION is 
returned by rsrc_mgr.c:pcmcia_adjust_resource_info() in !CONFIG_NONSTATIC.
But I'm not sure...

So, I will show you the driver's status as following.
I hope any comments if possible.

Thanks in advance.

-- Takata


Status of the M32R CF driver
~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    configuration                           : status
    --------------------------------------- + --------
    pccard_nonstatic_ops (CONFIG_NONSTATIC) : OK
    pccard_static_ops (!CONFIG_NONSTATIC)   : NG

    OK ... In NONSTATIC (CONFIG_NONSTATIC, pccard_nonstatic_ops) case,
           a CF disk/memory device can be probed and mounted normally.
  
    NG ... In STATIC (!CONFIG_NONSTATIC, pccard_static_ops) case,
           a CF disk/memory device can *not* be probed automatically now.
           But a CF device can be mounted after "pccardctl insert" command
           execution, and also a CF device insert event can be handled 
           correctly.


Config params
~~~~~~~~~~~~~
---
  :
#
# PCCARD (PCMCIA/CardBus) support
#
CONFIG_PCCARD=y
# CONFIG_PCMCIA_DEBUG is not set
CONFIG_PCMCIA=y
CONFIG_PCMCIA_LOAD_CIS=y
CONFIG_PCMCIA_IOCTL=y

#
# PC-card bridges
#
# CONFIG_TCIC is not set
# CONFIG_M32R_PCC is not set
CONFIG_M32R_CFC=y
CONFIG_M32R_CFC_NUM=1
  :
#
# ATA/ATAPI/MFM/RLL support
#
CONFIG_IDE=y
CONFIG_BLK_DEV_IDE=y
  :
#
# Please see Documentation/ide.txt for help/info on IDE drives
#
# CONFIG_BLK_DEV_IDE_SATA is not set
CONFIG_BLK_DEV_IDEDISK=y
# CONFIG_IDEDISK_MULTI_MODE is not set
CONFIG_BLK_DEV_IDECS=m
CONFIG_BLK_DEV_IDECD=m
# CONFIG_BLK_DEV_IDETAPE is not set
# CONFIG_BLK_DEV_IDEFLOPPY is not set
# CONFIG_IDE_TASK_IOCTL is not set

#
# IDE chipset support/bugfixes
#
CONFIG_IDE_GENERIC=y
# CONFIG_IDE_ARM is not set
# CONFIG_BLK_DEV_IDEDMA is not set
# CONFIG_IDEDMA_AUTO is not set
# CONFIG_BLK_DEV_HD is not set
  :
---
      

Test environment
~~~~~~~~~~~~~~~~~
  Platform: M3A-2170(Mappi-III)

  hotplug + pcmciautils
    - hotplug (0.0.20040329-22)
    - pcmciautils-003
      http://kernel.org/pub/linux/utils/kernel/pcmcia/pcmcia.html

  Root filesystem: based on Debian GNU/Linux (sid) for m32r.
  aptline:
    deb http://debian.linux-m32r.org 04_ordovician main
    deb http://debian.linux-m32r.org unstable main


Boot log messages
~~~~~~~~~~~~~~~~~
1) NONSTATIC (CONFIG_NONSTATIC), built-in driver  ... OK

   - A CF disk device can be probed correctly.
       hda: HMS360404D5CF00, CFA DISK drive
       ide0 at 0x1000-0x1007,0x100e on irq 6
       hda: max request size: 128KiB
       hda: 7999488 sectors (4095 MB) w/128KiB Cache, CHS=7936/16/63
       hda: cache flushes supported
       /dev/ide/host0/bus0/target0/lun0: p1
       ide-cs: hda: Vcc = 3.3, Vpp = 0.0

--- boot log ---
g00ff version -36.2 (M32R)
        Copyright 2004-2005  Free Software Initiative of Japan
eth: MAC Address: 08 00 70 25 6A 02, Ethernet initialization done.
DHCP success.
DNS resolved.
Address resolution (IP -> Ether MAC) success.
!
Loading kernel from network: ...........................
Uncompressing Linux... Ok, booting the kernel.
Linux version 2.6.12-rc5-mm1 (takata@pcepx10) (gcc version 3.4.4 20050203 (prerelease) (Debian 3.4.3-9.1)) #16 SMP Wed Jun 1 18:21:41 JST 2005
user-defined physical RAM map:
Built 2 zonelists
Initializing CPU#0
Kernel command line: console=ttyS0,115200n8 root=/dev/nfs nfsroot=/project/m32r-linux/export/rootfs2.6_04.unstable,rsize=1024,wsize=1024 ip=:::::eth0:dhcp mem=128M
PID hash table entries: 1024 (order: 10, 16384 bytes)
Timer start : latch = 3906
Dentry cache hash table entries: 32768 (order: 5, 131072 bytes)
Inode-cache hash table entries: 16384 (order: 4, 65536 bytes)
Memory: 128072k/131592k available (1592k kernel code, 3424k reserved, 291k data, 96k init)
Mount-cache hash table entries: 512
M32R-mp information
  On-chip CPUs : 2
  CPU model : M32R-MP 012U2/CHAOS(Ver.)
CPU present map : 3
Booting processor 1/1
Waiting for send to finish...
Initializing CPU#1
CPU#1 (phys ID: 1) waiting for CALLOUT
+After Startup.
Before Callout 1.
After Callout 1.
OK.
Boot done.
Brought up 2 CPUs
CPU#0 : CPU clock 200.00MHz, Bus clock 50.00MHz, loops_per_jiffy[794624]
CPU#1 : CPU clock 200.00MHz, Bus clock 50.00MHz, loops_per_jiffy[794624]
Before bogomips.
Total of 2 processors activated (317.84 BogoMIPS).
Before bogocount - setting activated=1.
NET: Registered protocol family 16
inotify device minor=63
devfs: 2004-01-31 Richard Gooch (rgooch@atnf.csiro.au)
devfs: boot_options: 0x1
JFFS version 1.0, (C) 1999, 2000  Axis Communications AB
JFFS2 version 2.2. (NAND) (C) 2001-2003 Red Hat, Inc.
cn_fork is registered
Serial: M32R SIO driver $Revision: 1.11 $ ttyS0 at I/O 0xefd000 (irq = 48) is a M32RSIO
io scheduler noop registered
io scheduler deadline registered
io scheduler cfq registered
RAMDISK driver initialized: 16 RAM disks of 4096K size 1024 blocksize
loop: loaded (max 8 devices)
smc91x.c: v1.1, sep 22 2004 by Nicolas Pitre <nico@cam.org>
eth0: SMC91C11xFD (rev 1) at a0000300 IRQ 1
eth0: Ethernet addr: 08:00:70:25:6a:02
Uniform Multi-Platform E-IDE driver Revision: 7.00alpha2
ide: Assuming 50MHz system bus speed for PIO modes; override with idebus=xx
CF: Card is detected at socket 0 : stat = 0x00000001
  m32r_cfc pcc at 0x00000000
mice: PS/2 mouse device common for all mice
NET: Registered protocol family 2
IP: routing cache hash table of 512 buckets, 8Kbytes
TCP established hash table entries: 8192 (order: 5, 131072 bytes)
TCP bind hash table entries: 8192 (order: 4, 98304 bytes)
TCP: Hash tables configured (established 8192 bind 8192)
NET: Registered protocol family 1
eth0: link down
Sending DHCP requests .<6>eth0: link up, 100Mbps, full-duplex, lpa 0x45E1
., OK
IP-Config: Got DHCP answer from 192.168.0.1, my address is 192.168.0.105
IP-Config: Complete:
      device=eth0, addr=192.168.0.105, mask=255.255.255.0, gw=255.255.255.255,
     host=mappi005, domain=, nis-domain=(none),
     bootserver=192.168.0.1, rootserver=192.168.0.1, rootpath=
Looking up port of RPC 100003/2 on 192.168.0.1
Looking up port of RPC 100005/1 on 192.168.0.1
VFS: Mounted root (nfs filesystem) readonly.
Mounted devfs on /dev
Freeing unused kernel memory: 96k freed
INIT: version 2.86 booting
Creating extra device nodes...done.  
Started device management daemon v1.3.25 for /dev
Activating swap.
Cannot access the Hardware Clock via any known method.
Use the --debug option to see the details of our search for an access method.
System time was Thu Apr 17 00:01:05 UTC 2003.
Setting the System Clock using the Hardware Clock as reference...
Cannot access the Hardware Clock via any known method.
Use the --debug option to see the details of our search for an access method.
System Clock set. System local time is now Thu Apr 17 09:01:06 JST 2003.
Cleaning up ifupdown...done.
Calculating module dependencies... done.
Loading modules...
All modules loaded.
Checking all file systems...
fsck 1.35 (28-Feb-2004)
Setting kernel variables ...
... done.
Mounting local filesystems...
mount: mount point /proc/bus/usb does not exist
Cleaning /tmp /var/run /var/lock.
/dev/shm/network/...Initializing: /etc/network/ifstate.
Starting hotplug subsystem:
   pci     
   pci      [success]
   usb     
   usb      [success]
   isapnp  
   isapnp   [success]
   ide     
   ide      [success]
   input   
   input    [success]
   pcmcia  
   pcmcia   [success]
   pcmcia_socket
   pcmcia_socket [success]
   scsi    
   scsi     [success]
done.
hda: HMS360404D5CF00, CFA DISK drive
Configuring network interfaces...ide0 at 0x1000-0x1007,0x100e on irq 6
hda: max request size: 128KiB
hda: 7999488 sectors (4095 MB) w/128KiB Cache, CHS=7936/16/63
hda: cache flushes supported
 /dev/ide/host0/bus0/target0/lun0: p1
ide-cs: hda: Vcc = 3.3, Vpp = 0.0
done.
Starting portmap daemon: portmap.
Starting portmapper...Mounting remote filesystems...

Setting the System Clock using the Hardware Clock as reference...
Cannot access the Hardware Clock via any known method.
Use the --debug option to see the details of our search for an access method.
System Clock set. Local time: Thu Apr 17 09:01:32 JST 2003

Initializing random number generator...done.
Setting up X server socket directory /tmp/.X11-unix...done.
Setting up ICE socket directory /tmp/.ICE-unix...done.
INIT: Entering runlevel: 2
Starting portmap daemon: portmap.
Starting internet superserver: inetd.
Starting OpenBSD Secure Shell server: sshd.

Debian GNU/Linux 3.1 mappi001 ttyS0

mappi001 login: 
---
The hda device is detected correctly.


2) STATIC (!CONFIG_NONSTATIC), built-in driver  ... NG

  - A CF disk/memory device is not recognized automatically at boot time.
  - However, after boot, "pccardctl insert" works normally, and 
    a CF disk/memory device can be mounted, and CF device insertion
    events can be handled correctly.

--- boot log ---
 :
Starting hotplug subsystem:
   pci     
   pci      [success]
   usb     
   usb      [success]
   isapnp  
   isapnp   [success]
   ide     
   ide      [success]
   input   
   input    [success]
   pcmcia  
   pcmcia   [success]
   pcmcia_socket
   pcmcia_socket [success]
   scsi    
   scsi     [success]
done.
Configuring network interfaces...done.
Starting portmap daemon: portmap.
Starting portmapper...Mounting remote filesystems...
 :
---
No CF device is recognized at boot time.

^ permalink raw reply	[flat|nested] 5+ messages in thread

* [PATCH 2.6.12-rc5-mm2] m32r: m32r_cfc.c build fix
  2005-06-01 11:57   ` Hirokazu Takata
@ 2005-06-02 10:11     ` Hirokazu Takata
  0 siblings, 0 replies; 5+ messages in thread
From: Hirokazu Takata @ 2005-06-02 10:11 UTC (permalink / raw)
  To: Andrew Morton; +Cc: linux, linux-pcmcia, sakugawa, linux-kernel, takata

I made a patch to fix a build error of m32r_cfc.c in 2.6.12-rc5-mm2 kernel.
This patch selects CONFIG_NONSTATIC for M32R PCMCIA/CF drivers.

Signed-off-by: Hirokazu Takata <takata@linux-m32r.org>
---

 drivers/pcmcia/Kconfig |    2 ++
 1 files changed, 2 insertions(+)

diff -ruNp a/drivers/pcmcia/Kconfig b/drivers/pcmcia/Kconfig
--- a/drivers/pcmcia/Kconfig	2005-06-01 15:33:47.000000000 +0900
+++ b/drivers/pcmcia/Kconfig	2005-06-01 22:01:50.000000000 +0900
@@ -198,12 +198,14 @@ config PCMCIA_PROBE
 config M32R_PCC
 	bool "M32R PCMCIA I/F"
 	depends on M32R && CHIP_M32700 && PCMCIA
+	select PCCARD_NONSTATIC
 	help
 	  Say Y here to use the M32R PCMCIA controller.
 
 config M32R_CFC
 	bool "M32R CF I/F Controller"
 	depends on M32R && (PLAT_USRV || PLAT_M32700UT || PLAT_MAPPI2 || PLAT_MAPPI3 || PLAT_OPSPUT)
+	select PCCARD_NONSTATIC
 	help
 	  Say Y here to use the M32R CompactFlash controller.
 
diff -ruNp a/drivers/pcmcia/m32r_cfc.c b/drivers/pcmcia/m32r_cfc.c
--- a/drivers/pcmcia/m32r_cfc.c	2005-05-26 18:54:43.000000000 +0900
+++ b/drivers/pcmcia/m32r_cfc.c	2005-05-26 20:38:13.000000000 +0900
@@ -24,9 +24,9 @@
 #include <linux/workqueue.h>
 #include <linux/interrupt.h>
 #include <linux/device.h>
+#include <linux/bitops.h>
 #include <asm/irq.h>
 #include <asm/io.h>
-#include <asm/bitops.h>
 #include <asm/system.h>
 
 #include <pcmcia/version.h>
@@ -444,7 +444,7 @@ static int _pcc_get_status(u_short sock,
 		debug(3, "m32r_cfc: _pcc_get_status: "
 			 "power off (CPCR=0x%08x)\n", status);
 	}
-#elif defined(CONFIG_PLAT_MAPPI2)
+#elif defined(CONFIG_PLAT_MAPPI2) || defined(CONFIG_PLAT_MAPPI3)
 	if ( status ) {
 		status = pcc_get(sock, (unsigned int)PLD_CPCR);
 		if (status == 0) { /* power off */
@@ -452,18 +452,23 @@ static int _pcc_get_status(u_short sock,
 			pcc_set(sock, (unsigned int)PLD_CFBUFCR,0); /* force buffer off for ZA-36 */
 			udelay(50);
 		}
-		status = pcc_get(sock, (unsigned int)PLD_CFBUFCR);
-		if (status != 0) { /* buffer off */
-			pcc_set(sock, (unsigned int)PLD_CFBUFCR,0);
-			udelay(50);
-			pcc_set(sock, (unsigned int)PLD_CFRSTCR, 0x0101);
-			udelay(25); /* for IDE reset */
-			pcc_set(sock, (unsigned int)PLD_CFRSTCR, 0x0100);
-			mdelay(2);  /* for IDE reset */
-		} else {
-			*value |= SS_POWERON;
-			*value |= SS_READY;
-		}
+		*value |= SS_POWERON;
+
+		pcc_set(sock, (unsigned int)PLD_CFBUFCR,0);
+		udelay(50);
+		pcc_set(sock, (unsigned int)PLD_CFRSTCR, 0x0101);
+		udelay(25); /* for IDE reset */
+		pcc_set(sock, (unsigned int)PLD_CFRSTCR, 0x0100);
+		mdelay(2);  /* for IDE reset */
+
+		*value |= SS_READY;
+		*value |= SS_3VCARD;
+	} else {
+		/* disable CF power */
+	        pcc_set(sock, (unsigned int)PLD_CPCR, 0);
+		udelay(100);
+		debug(3, "m32r_cfc: _pcc_get_status: "
+			 "power off (CPCR=0x%08x)\n", status);
 	}
 #else
 #error no platform configuration
@@ -479,14 +484,13 @@ static int _pcc_get_socket(u_short sock,
 {
 //	pcc_socket_t *t = &socket[sock];
 
-#if defined(CONFIG_PLAT_M32700UT) || defined(CONFIG_PLAT_USRV) || defined(CONFIG_PLAT_OPSPUT)
 	state->flags = 0;
 	state->csc_mask = SS_DETECT;
 	state->csc_mask |= SS_READY;
 	state->io_irq = 0;
 	state->Vcc = 33;	/* 3.3V fixed */
 	state->Vpp = 33;
-#endif
+
 	debug(3, "m32r_cfc: GetSocket(%d) = flags %#3.3x, Vcc %d, Vpp %d, "
 		  "io_irq %d, csc_mask %#2.2x\n", sock, state->flags,
 		  state->Vcc, state->Vpp, state->io_irq, state->csc_mask);
@@ -497,32 +501,17 @@ static int _pcc_get_socket(u_short sock,
 
 static int _pcc_set_socket(u_short sock, socket_state_t *state)
 {
-#if defined(CONFIG_PLAT_MAPPI2)
-	u_long reg = 0;
-#endif
 	debug(3, "m32r_cfc: SetSocket(%d, flags %#3.3x, Vcc %d, Vpp %d, "
 		  "io_irq %d, csc_mask %#2.2x)\n", sock, state->flags,
 		  state->Vcc, state->Vpp, state->io_irq, state->csc_mask);
 
-#if defined(CONFIG_PLAT_M32700UT) || defined(CONFIG_PLAT_USRV) || defined(CONFIG_PLAT_OPSPUT)
+#if defined(CONFIG_PLAT_M32700UT) || defined(CONFIG_PLAT_USRV) || defined(CONFIG_PLAT_OPSPUT) || defined(CONFIG_PLAT_MAPPI2) || defined(CONFIG_PLAT_MAPPI3)
 	if (state->Vcc) {
 		if ((state->Vcc != 50) && (state->Vcc != 33))
 			return -EINVAL;
 		/* accept 5V and 3.3V */
 	}
-#elif defined(CONFIG_PLAT_MAPPI2)
-	if (state->Vcc) {
-		/*
-		 * 5V only
-		 */
-		if (state->Vcc == 50) {
-			reg |= PCCSIGCR_VEN;
-		} else {
-			return -EINVAL;
-		}
-	}
 #endif
-
 	if (state->flags & SS_RESET) {
 		debug(3, ":RESET\n");
 		pcc_set(sock,(unsigned int)PLD_CFRSTCR,0x101);
@@ -788,7 +777,7 @@ static int __init init_m32r_pcc(void)
 		return ret;
 	}
 
-#if defined(CONFIG_PLAT_MAPPI2)
+#if defined(CONFIG_PLAT_MAPPI2) || defined(CONFIG_PLAT_MAPPI3)
 	pcc_set(0, (unsigned int)PLD_CFCR0, 0x0f0f);
 	pcc_set(0, (unsigned int)PLD_CFCR1, 0x0200);
 #endif
@@ -825,7 +814,7 @@ static int __init init_m32r_pcc(void)
 	for (i = 0 ; i < pcc_sockets ; i++) {
 		socket[i].socket.dev.dev = &pcc_device.dev;
 		socket[i].socket.ops = &pcc_operations;
-		socket[i].socket.resource_ops = &pccard_static_ops;
+		socket[i].socket.resource_ops = &pccard_nonstatic_ops;
 		socket[i].socket.owner = THIS_MODULE;
 		socket[i].number = i;
 		ret = pcmcia_register_socket(&socket[i].socket);
--
Hirokazu Takata <takata@linux-m32r.org>
Linux/M32R Project:  http://www.linux-m32r.org/

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2005-06-02 10:11 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2005-05-31 13:17 [PATCH 2.6.12-rc5] m32r: Update m32r_cfc.[ch] to support Mappi-III platform Hirokazu Takata
2005-05-31 14:19 ` Christoph Hellwig
2005-05-31 14:45 ` Dominik Brodowski
2005-06-01 11:57   ` Hirokazu Takata
2005-06-02 10:11     ` [PATCH 2.6.12-rc5-mm2] m32r: m32r_cfc.c build fix Hirokazu Takata

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®